==> haskell-contravariant-extras-0.3.3.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant-extras
version: 0.3.3.1
id: contravariant-extras-0.3.3.1-6AvuWK4Qahw4D6uBR5fRq7
key: contravariant-extras-0.3.3.1-6AvuWK4Qahw4D6uBR5fRq7
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/contravariant-extras
synopsis: Extras for the "contravariant" package
category: Control
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.Op Contravariant.Extras.Op.Contrazip
hidden-modules: Contravariant.Extras.TH
abi: 5fee5a51710e131d36547a34c7b43819
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/contravariant-extras-0.3.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/contravariant-extras-0.3.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/contravariant-extras-0.3.3.1
hs-libraries: HScontravariant-extras-0.3.3.1-6AvuWK4Qahw4D6uBR5fRq7
depends:
    base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
    contravariant-1.4-KgMYVwXYQBGKuyyJtYdP11 template-haskell-2.11.0.0
    tuple-th-0.2.5-3w3e3WQ1jmi8zIzFwGGKsB
haddock-interfaces: /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock
haddock-html: /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-extras-0.3.3.1-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant-extras
version: 0.3.3.1
id: contravariant-extras-0.3.3.1-6JwLhf1IH33AIT8qu08gpr
key: contravariant-extras-0.3.3.1-6JwLhf1IH33AIT8qu08gpr
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/contravariant-extras
synopsis: Extras for the "contravariant" package
category: Control
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.Op Contravariant.Extras.Op.Contrazip
hidden-modules: Contravariant.Extras.TH
abi: 77355138405a7f71d2a34cfad821eb42
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/contravariant-extras-0.3.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/contravariant-extras-0.3.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/contravariant-extras-0.3.3.1
hs-libraries: HScontravariant-extras-0.3.3.1-6JwLhf1IH33AIT8qu08gpr
depends:
    base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
    contravariant-1.4-BhMeiKXigEF6jqFehOEdeG template-haskell-2.11.0.0
    tuple-th-0.2.5-3w3e3WQ1jmi8zIzFwGGKsB
haddock-interfaces: /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock
haddock-html: /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
